@@ -161,7 +161,7 @@ void export_glyphs(struct font_s *font)
   if(!f) goto file_error;
 
   fprintf(f, "#fontopia glyph file\n");
-  fprintf(f, "# This files contains a textual representation of the\n");
+  fprintf(f, "# This file contains a textual representation of the\n");
   fprintf(f, "# glyphs of (%s).\n", font_file_name);
   fprintf(f, "# This file is informative only, as the actual font file\n");
   fprintf(f, "# may have been modified in fontopia. Currently you can not\n");
@@ -199,7 +199,7 @@ void export_glyphs(struct font_s *font)
 	fprintf(f, "%c", (line & mask) ? 'X' : ' ');
 	mask >>= 1;
       }
-      fprintf(f, "\n");
+      fprintf(f, "|\n");
       //data += h;
     }
     data += font->charsize;
