@@ -18,6 +18,7 @@
  *    along with fontopia.  If not, see <http://www.gnu.org/licenses/>.
  */    
 
+#include <ctype.h>
 #include "../defs.h"
 #include "../view.h"
 #include "../metadata.h"
@@ -415,14 +416,51 @@ struct font_s *bdf_load_font(unsigned char *file_data, long file_size)
 		scope = BDF_GLYPH_SCOPE;
 		skip_spaces(&s);
 		/* check if it is Unicode-encoded */
+                unsigned int chr = 0;
 		if(s[0] != 'U' || s[1] != '+')
 		{
-		  status_error("Char encoding not in Unicode. Can't read that!");
-		  //msgBox("Char encoding not in Unicode. Can't read that!", OK, ERROR);
-		  goto go;
+		  if(*s >= '2' && *s <= '7') chr = codepoint_to_unicode(s);
+		  else
+                  {
+                      chr = postscript_to_unicode(s);
+                      if(!chr)
+                      {
+                          chr = codepoint_to_unicode(s);
+                      }
+                  }
+                  /*
+                  if((*s >= 'A' && *s <= 'F') ||
+                          (*s >= 'a' && *s <= 'f'))
+                  {
+                      if(isspace(*(s+1)) || *(s+1) == '\0') chr = postscript_to_unicode(s);
+                      else 
+                      {
+                          if((*(s+1) >= '0' && *(s+1) <= '9') ||
+                              (*(s+1) >= 'A' && *(s+1) <= 'F') ||
+                              (*(s+1) >= 'a' && *(s+1) <= 'f'))
+                          {
+                              if(isspace(*(s+2)) || *(s+2) == '\0') chr = codepoint_to_unicode(s);
+                              else chr = postscript_to_unicode(s);
+                          }
+                          else chr = postscript_to_unicode(s);
+                      }
+                  }
+                  else if (isalpha(*s)) chr = postscript_to_unicode(s);
+                  */
+                  if(!chr)
+                  {
+                      msgBox("Char name not in Unicode, Adobe\n"
+                                    "Standard Encoding, or Postscript char\n"
+                                    "name. I Can't read this encoding!", OK, ERROR);
+                      ////status_error("Char encoding not in Unicode. Can't read that!", OK, ERROR);
+                      goto go;
+                  }
 		}
-		s += 2;
-		unsigned int chr = get_hex(s, 4);
+		else
+                {
+                    s += 2;
+                    chr = get_hex(s, 4);
+                }
 		unicode_info[chars*2] = (unsigned short)chr;
 		unicode_info[(chars*2)+1] = 0xFFFF;
 	  }
