@@ -125,15 +125,16 @@ void refresh_right_window(struct font_s *font)
   int row = 0;
   int col = 0;
   int i = 0;
-  int old_i = -1;
-  int j = 0;
+  //int old_i = -1;
+  //int j = 0;
   unsigned short c = 0;
   unsigned char wc[5];
   font->unicode_array_index = 0;
   font->unicode_index = 0;
 
   /* first clear old canvas */
-  for(i = 0; i < right_window.height-1; i++)
+  setScreenColors(WHITE, BGDEFAULT);
+  for(i = 0; i < right_window.height; i++)
   {
     locate(right_window.start_row+i, right_window.start_col);
     printf("%*s", right_window.width, " ");
@@ -201,87 +202,18 @@ void refresh_right_window(struct font_s *font)
   }
   fflush(stdout);
   return;
-  
-  
-
-
-  
-  
-  
-  
-  
-  
-    
-    
-    
-    
-  while(i < font->length)
-  {
-    if(!font->has_unicode_table)
-    {
-      if(right_window.cursor.row == row &&
-	 right_window.cursor.col == col/2)
-	setScreenColors(BLACK, BGWHITE);
-      else
-	setScreenColors(WHITE, BGDEFAULT);
-      printf("%02x", j++);
-      i++; col += 2;
-      if(col == right_window.width)
-      {
-	row++;
-	if(row == right_window.height) break;
-	col = 0;
-	locate(right_window.start_row+row, right_window.start_col+col);
-      }
-      continue;
-    }
-    c = get_next_utf(font);
-    if(c == PSF1_SEPARATOR)
-    {
-      old_i = i; i++;
-      continue;
-    }
-    else if(c == PSF1_STARTSEQ)
-    {
-      /*
-       * NOTE: we are discarding unicode sequences.
-       * TODO: fix this!.
-       */
-      do
-      {
-	c = get_next_utf(font);
-      } while(c != PSF1_SEPARATOR);
-      old_i = i; i++;
-      continue;
-    }
-
-    if(old_i == i) continue;
-    if(right_window.cursor.row == row &&
-       right_window.cursor.col == col)
-      setScreenColors(BLACK, BGWHITE);
-    else
-      setScreenColors(WHITE, BGDEFAULT);
-    memset((void *)wc, 0, 5);
-    make_utf8(wc, c);
-    if(wc[0] == 0xa0 || wc[0] == 0x0) putchar(' ');
-    else printf("%s", wc);
-    //fflush(stdout);
-    old_i = i;
-//next:
-    col++;
-    if(col == right_window.width)
-    {
-      row++;
-      if(row == right_window.height) break;
-      col = 0;
-      locate(right_window.start_row+row, right_window.start_col+col);
-    }
-  }
-  fflush(stdout);
 }
 
 void refresh_left_window(struct font_s *font)
 {
+  int bail_out = 0;
+  if((left_window.width < font->width+6) || (left_window.height < font->height+2))
+  {
+      msgBox("Can't display glyph. Font metrics\n"
+             "(weight or height) larger than screen\n"
+             "size.", OK, ERROR);
+      bail_out = 1;
+  }
   int col_midpoint = (left_window.width-(font->width*font->current_zoom)) >> 1;
   int row_midpoint = (left_window.height-(font->height*font->current_zoom)) >> 1;
   int col = left_window.start_col + col_midpoint;
@@ -290,16 +222,6 @@ void refresh_left_window(struct font_s *font)
   int j;
   unsigned char *data = font->data;
   data += get_glyph_index(font);
-  /*
-  if(!font->has_unicode_table)
-  {
-    data += (right_window.cursor.row*(right_window.width/2) + right_window.cursor.col)*font->charsize;
-  }
-  else
-  {
-    data += (right_window.cursor.row*right_window.width + right_window.cursor.col)*font->charsize;
-  }
-  */
   setScreenColors(WHITE, BGDEFAULT);
   char X[10], O[10];
   for(j = 0; j < zoom; j++) { X[j] = 'X'; O[j] = '-'; }
@@ -311,28 +233,31 @@ void refresh_left_window(struct font_s *font)
     locate(left_window.start_row+j, left_window.start_col);
     printf("%*s", left_window.width, " ");
   }
+  if(bail_out) return;
   
   int actual_row = row;
+  unsigned int base_index = (1 << (font->width - 1));
+  if(font->width < 8) base_index <<= (8-font->width);
+  else if(font->width > 8 && font->width < 16) base_index <<= (16-font->width);
+  else if(font->width > 16 && font->width < 32) base_index <<= (32-font->width);
   /* Then draw glyph */
   for(j = 0; j < font->height; j++)
   {
-    int line, index;
-    index = (1 << (font->width - 1));
+    unsigned int line, index;
+    index = base_index;
     if(font->width <= 8)
     {
-      line = (int)data[0]; data++;
-      if(font->width < 8) index <<= (8-font->width);
+      line = (unsigned int)data[0]; data++;
     }
     else if(font->width <= 16)
     {
-      line = (int)(data[0] | (int)(data[1] << 8));
-      if(font->width < 16) index <<= (16-font->width);
+      line = (unsigned int)(data[0] | (unsigned int)(data[1] << 8));
       data += 2;
     }
     else if(font->width <= 32)
     {
-      line = (int)(data[0] | ((int)(data[1]) << 8) | ((int)(data[2]) << 16) | ((int)(data[3] << 24)));
-      if(font->width < 32) index <<= (32-font->width);
+      line = (unsigned int)(data[0] | ((unsigned int)(data[1]) << 8) | 
+                ((unsigned int)(data[2]) << 16) | ((unsigned int)(data[3] << 24)));
       data += 4;
     }
     /* 
@@ -466,10 +391,11 @@ void create_status_msg(char *smsg, char *msg, struct font_s *font)
 void _refresh_view(char *msg, int status, struct font_s *font)
 {
   /* clear the screen */
-  clearScreen();
-  setScreenColors(WHITE, BGBLACK);
+  setScreenColors(WHITE, BGDEFAULT);
+  //clearScreen();
   /* draw main window */
-  drawBox(1, 1, SCREEN_H, SCREEN_W, " Fontopia for GNU/Linux ", YES);
+  drawBox(1, 1, SCREEN_H, SCREEN_W, " Fontopia for GNU/Linux ", NO);
+  //drawBox(1, 1, SCREEN_H, SCREEN_W, " Fontopia for GNU/Linux ", YES);
   refresh_right_window(font);
   refresh_left_window(font);
 
